FileHeader

Struct FileHeader 

pub struct FileHeader {
    pub filename: PathBuf,
    pub unpacked_size: u64,
    pub file_crc: u32,
    pub file_time: u32,
    pub method: u32,
    pub file_attr: u32,
    /* private fields */
}
Metadata for an entry in a RAR archive

Created using the read_header methods in an OpenArchive, contains information for the file that follows which is to be processed next.

Fields

filename: PathBufunpacked_size: u64file_crc: u32file_time: u32method: u32file_attr: u32

Implementations

Source

impl FileHeader

pub fn is_split(&self) -> bool

is this entry split across multiple volumes.

Will also work in open mode List

pub fn is_split_after(&self) -> bool

is this entry split across multiple volumes, starting here

Will also work in open mode List

pub fn is_split_before(&self) -> bool

is this entry split across multiple volumes, starting here

Will always return false in open mode List1.


  1. this claim is not proven, however, the DLL seems to always skip files where this flag would have been set. 

pub fn is_directory(&self) -> bool

is this entry a directory

pub fn is_encrypted(&self) -> bool

is this entry encrypted

pub fn is_file(&self) -> bool

is this entry a file