pub struct FileHeader {
pub filename: PathBuf,
pub unpacked_size: u64,
pub file_crc: u32,
pub file_time: u32,
pub method: u32,
pub file_attr: u32,
/* private fields */
}Expand description
Metadata for an entry in a RAR archive
Created using the read_header methods in an OpenArchive, contains information for the file that follows which is to be processed next.
Fields
filename: PathBufunpacked_size: u64file_crc: u32file_time: u32method: u32file_attr: u32Implementations
Sourceimpl FileHeader
impl FileHeader
Sourcepub fn is_split(&self) -> bool
pub fn is_split(&self) -> bool
is this entry split across multiple volumes.
Will also work in open mode List
Sourcepub fn is_split_after(&self) -> bool
pub fn is_split_after(&self) -> bool
is this entry split across multiple volumes, starting here
Will also work in open mode List
Sourcepub fn is_split_before(&self) -> bool
pub fn is_split_before(&self) -> bool
Sourcepub fn is_directory(&self) -> bool
pub fn is_directory(&self) -> bool
is this entry a directory
Sourcepub fn is_encrypted(&self) -> bool
pub fn is_encrypted(&self) -> bool
is this entry encrypted